==> sceditor-8.x-1.1.tar.gz: sceditor/src/Form/FTPAccessForm.php <==
<?php

namespace Drupal\sceditor\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class FTPAccessForm.
 */
class FTPAccessForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'sceditor.ftpaccess',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ftp_access_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $this->checkFTPStatus();
    $config = $this->config('sceditor.ftpaccess');
    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#maxlength' => 32,
      '#size' => 32,
      '#default_value' => $config->get('username'),
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#maxlength' => 32,
      '#size' => 32,
      '#default_value' => $config->get('password'),
    ];
    $form['advanced'] = [
      '#type' => 'details',
      '#title' => $this->t('Advanced'),
    ];
    $form['advanced']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => ($config->get('host')) ? $config->get('host') : 'localhost',
    ];
    $form['advanced']['port'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Port'),
      '#maxlength' => 16,
      '#size' => 16,
      '#default_value' => ($config->get('port')) ? $config->get('port') : 21,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('sceditor.ftpaccess')
      ->set('username', $form_state->getValue('username'))
      ->set('password', $form_state->getValue('password'))
      ->set('host', $form_state->getValue('host'))
      ->set('port', $form_state->getValue('port'))
      ->save();

  }

  /**
   * Check id the FTP Access is available.
   */
  public function checkFTPStatus() {
    $config = \Drupal::config('sceditor.ftpaccess');
    $ftp_server = $config->get('host');
    $ftp_user = $config->get('username');
    $ftp_pass = $config->get('password');
    $ftp = (empty($ftp_server)) ? FALSE : ftp_connect($ftp_server);
    if (!$ftp || !ftp_login($ftp, $ftp_user, $ftp_pass)) {
      drupal_set_message($this->t('FTP is not connected. If you want to edit using FTP, please check your FTP settings in your server and/or check the FTP Credentials below.'), 'warning');
    }
  }

}

==> sceditor-8.x-1.2.tar.gz: sceditor/src/Form/FTPAccessForm.php <==
<?php

namespace Drupal\sceditor\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class FTPAccessForm.
 */
class FTPAccessForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'sceditor.ftpaccess',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ftp_access_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $this->checkFTPStatus();
    $config = $this->config('sceditor.ftpaccess');
    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#maxlength' => 32,
      '#size' => 32,
      '#default_value' => $config->get('username'),
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#maxlength' => 32,
      '#size' => 32,
      '#default_value' => $config->get('password'),
    ];
    $form['advanced'] = [
      '#type' => 'details',
      '#title' => $this->t('Advanced'),
    ];
    $form['advanced']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => ($config->get('host')) ? $config->get('host') : 'localhost',
    ];
    $form['advanced']['port'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Port'),
      '#maxlength' => 16,
      '#size' => 16,
      '#default_value' => ($config->get('port')) ? $config->get('port') : 21,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('sceditor.ftpaccess')
      ->set('username', $form_state->getValue('username'))
      ->set('password', $form_state->getValue('password'))
      ->set('host', $form_state->getValue('host'))
      ->set('port', $form_state->getValue('port'))
      ->save();

  }

  /**
   * Check id the FTP Access is available.
   */
  public function checkFtpStatus() {
    $config = \Drupal::config('sceditor.ftpaccess'); // @codingStandardsIgnoreLine
    $ftp_server = $config->get('host');
    $ftp_user = $config->get('username');
    $ftp_pass = $config->get('password');
    $ftp = (empty($ftp_server)) ? FALSE : ftp_connect($ftp_server);
    if (!$ftp || !ftp_login($ftp, $ftp_user, $ftp_pass)) {
      drupal_set_message($this->t('FTP is not connected. If you want to edit using FTP, please check your FTP settings in your server and/or check the FTP Credentials below.'), 'warning');
    }
  }

}
